==> loco-mujoco-0.2.2.tar.gz: loco-mujoco-0.2.2/loco_mujoco/environments/README.md <==
# Overview of Available Tasks
Here you can find an overviw of all tasks. Each Task is represented by its own ID. For each task, you can choose between different datasets. The real dataset contains real (noisy) motion capture datasets without actions. The perfect dataset contains ground truth states and actions form an expert policy (only available on an few tasks). The preference dataset contains preferences of an ground truth expert with states and action (only available on an few tasks). 
The status of a dataset can be seen down below. ✅ means it is already available, and 🔶 means pending. 

 | Image | Task-IDs | Status of Datasets | Description|
 |---|---|---|---|
 | ![out5](https://github.com/robfiras/loco-mujoco/assets/69359729/cdcd4617-c18a-448d-b42a-ea01384016b0) | HumanoidMuscle.walk </br> HumanoidMuscle.run </br> HumanoidMuscle4Ages.walk.4 </br> HumanoidMuscle.run </br> HumanoidMuscle4Ages.run.4 | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Task of an adult **Muscle** Humanoid Walking or Running Straight. |
 | ![out4](https://github.com/robfiras/loco-mujoco/assets/69359729/1bdebeb1-401c-439e-8f2e-7197fd34c5e5) | HumanoidMuscle4Ages.walk.3 </br> HumanoidMuscle4Ages.run.3  | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~12 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/2c7aeb58-65a6-427c-8b12-197c96410cd8) | HumanoidMuscle4Ages.walk.2 </br> HumanoidMuscle4Ages.run.2 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~5-6 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/600a917f-c784-4b5e-ac99-9472711de843) | HumanoidMuscle4Ages.walk.1 </br> HumanoidMuscle4Ages.run.1 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~2 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out39](https://github.com/robfiras/loco-mujoco/assets/69359729/cf32520f-5a2e-401a-9f2e-b8033ef7109c) | HumanoidTorque.walk </br> HumanoidTorque.run </br> HumanoidTorque4Ages.walk.4 </br> HumanoidTorque.run </br> HumanoidTorque4Ages.run.4 | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Task of an adult **Torque** Humanoid Walking or Running Straight. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/352f3594-8903-4eaf-a223-f751b590f4ec) | HumanoidTorque4Ages.walk.3 </br> HumanoidTorque4Ages.run.3  | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~12 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out5](https://github.com/robfiras/loco-mujoco/assets/69359729/06c83af9-3c45-43a1-8173-aa1d8771fe4c) | HumanoidTorque4Ages.walk.2 </br> HumanoidTorque4Ages.run.2 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~5-6 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/5ec93baa-bed8-4d9f-b983-3bc12264b9b6) | HumanoidTorque4Ages.walk.1 </br> HumanoidTorque4Ages.run.1 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~2 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out8](https://github.com/robfiras/loco-mujoco/assets/69359729/fed0315c-921e-4b2e-a9c2-54b85198ef65) | UnitreeH1.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeH1 Straight Walking Task. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/ab0dec59-fc24-4763-8ff6-38d58ac3b3de) | UnitreeH1.run  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeH1 Straight Running Task. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/851ff3c0-d05f-4de1-a00b-7b3204056e2f) | UnitreeH1.carry | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| UnitreeH1 Carry Task. |
 | ![out7](https://github.com/robfiras/loco-mujoco/assets/69359729/22c7bb0c-ff92-4e99-a964-7654df6d22c4) | Talos.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Talos Straight Walking Task. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/0ba1f0e7-1f3d-4088-a44f-0a53bec1cf3a) | Talos.carry  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| Talos Carry Task. |
 | ![out13](https://github.com/robfiras/loco-mujoco/assets/69359729/1ff09d98-e46b-429c-ac07-87de58853d28) | Atlas.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Atlas Straight Walking Task. |
 | ![out10](https://github.com/robfiras/loco-mujoco/assets/69359729/3c433333-3466-445b-b39f-2f990553d5ff) | Atlas.carry  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| Atlas Carry Task. |
 | ![out4](https://github.com/robfiras/loco-mujoco/assets/69359729/b722bb42-a26c-4692-b1a8-c6f71a78e37b) | UnitreeA1.simple  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeA1 Straight Walking Task. |
 | ![out47](https://github.com/robfiras/loco-mujoco/assets/69359729/5a1f783e-8b52-4680-a22b-d96f89faf9b3) | UnitreeA1.hard  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeA1 Walking in 8 Different Direction Task. |

==> loco-mujoco-0.3.0.tar.gz: loco-mujoco-0.3.0/loco_mujoco/environments/README.md <==
# Overview of Available Tasks
Here you can find an overviw of all tasks. Each Task is represented by its own ID. For each task, you can choose between different datasets. The real dataset contains real (noisy) motion capture datasets without actions. The perfect dataset contains ground truth states and actions form an expert policy (only available on an few tasks). The preference dataset contains preferences of an ground truth expert with states and action (only available on an few tasks). 
The status of a dataset can be seen down below. ✅ means it is already available, and 🔶 means pending. 

 | Image | Task-IDs | Status of Datasets | Description|
 |---|---|---|---|
 | ![out5](https://github.com/robfiras/loco-mujoco/assets/69359729/cdcd4617-c18a-448d-b42a-ea01384016b0) | HumanoidMuscle.walk </br> HumanoidMuscle.run </br> HumanoidMuscle4Ages.walk.4 </br> HumanoidMuscle.run </br> HumanoidMuscle4Ages.run.4 | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Task of an adult **Muscle** Humanoid Walking or Running Straight. |
 | ![out4](https://github.com/robfiras/loco-mujoco/assets/69359729/1bdebeb1-401c-439e-8f2e-7197fd34c5e5) | HumanoidMuscle4Ages.walk.3 </br> HumanoidMuscle4Ages.run.3  | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~12 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/2c7aeb58-65a6-427c-8b12-197c96410cd8) | HumanoidMuscle4Ages.walk.2 </br> HumanoidMuscle4Ages.run.2 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~5-6 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/600a917f-c784-4b5e-ac99-9472711de843) | HumanoidMuscle4Ages.walk.1 </br> HumanoidMuscle4Ages.run.1 | real: ✅  <br /> perfect: 🔶  <br /> preference: 🔶 | Task of a (~2 year old) **Muscle** Humanoid Walking or Running Straight. |
 | ![out39](https://github.com/robfiras/loco-mujoco/assets/69359729/cf32520f-5a2e-401a-9f2e-b8033ef7109c) | HumanoidTorque.walk </br> HumanoidTorque.run </br> HumanoidTorque4Ages.walk.4 </br> HumanoidTorque.run </br> HumanoidTorque4Ages.run.4 | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Task of an adult **Torque** Humanoid Walking or Running Straight. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/352f3594-8903-4eaf-a223-f751b590f4ec) | HumanoidTorque4Ages.walk.3 </br> HumanoidTorque4Ages.run.3  | real: ✅  <br /> perfect: ✅  <br /> preference: 🔶 | Task of a (~12 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out5](https://github.com/robfiras/loco-mujoco/assets/69359729/06c83af9-3c45-43a1-8173-aa1d8771fe4c) | HumanoidTorque4Ages.walk.2 </br> HumanoidTorque4Ages.run.2 | real: ✅  <br /> perfect: ✅  <br /> preference: 🔶 | Task of a (~5-6 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/5ec93baa-bed8-4d9f-b983-3bc12264b9b6) | HumanoidTorque4Ages.walk.1 </br> HumanoidTorque4Ages.run.1 | real: ✅  <br /> perfect: ✅  <br /> preference: 🔶 | Task of a (~2 year old) **Torque** Humanoid Walking or Running Straight. |
 | ![out8](https://github.com/robfiras/loco-mujoco/assets/69359729/fed0315c-921e-4b2e-a9c2-54b85198ef65) | UnitreeH1.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeH1 Straight Walking Task. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/ab0dec59-fc24-4763-8ff6-38d58ac3b3de) | UnitreeH1.run  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeH1 Straight Running Task. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/851ff3c0-d05f-4de1-a00b-7b3204056e2f) | UnitreeH1.carry | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| UnitreeH1 Carry Task. |
 | ![out8](https://github.com/robfiras/loco-mujoco/assets/69359729/e9a33e94-65e4-48f5-8d7a-3d103c4ec7f5) | UnitreeG1.walk  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| UnitreeG1 Straight Walking Task. |
 | ![out9](https://github.com/robfiras/loco-mujoco/assets/69359729/57292ef1-c152-4cd3-b7c1-d9a1e0633481) | UnitreeG1.run  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| UnitreeG1 Straight Running Task. |
 | ![out7](https://github.com/robfiras/loco-mujoco/assets/69359729/22c7bb0c-ff92-4e99-a964-7654df6d22c4) | Talos.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Talos Straight Walking Task. |
 | ![out3](https://github.com/robfiras/loco-mujoco/assets/69359729/0ba1f0e7-1f3d-4088-a44f-0a53bec1cf3a) | Talos.carry  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| Talos Carry Task. |
 | ![out13](https://github.com/robfiras/loco-mujoco/assets/69359729/1ff09d98-e46b-429c-ac07-87de58853d28) | Atlas.walk  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| Atlas Straight Walking Task. |
 | ![out10](https://github.com/robfiras/loco-mujoco/assets/69359729/3c433333-3466-445b-b39f-2f990553d5ff) | Atlas.carry  | real: ✅  <br /> perfect: 🔶   <br /> preference: 🔶| Atlas Carry Task. |
 | ![out4](https://github.com/robfiras/loco-mujoco/assets/69359729/b722bb42-a26c-4692-b1a8-c6f71a78e37b) | UnitreeA1.simple  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeA1 Straight Walking Task. |
 | ![out47](https://github.com/robfiras/loco-mujoco/assets/69359729/5a1f783e-8b52-4680-a22b-d96f89faf9b3) | UnitreeA1.hard  | real: ✅  <br /> perfect: ✅   <br /> preference: 🔶| UnitreeA1 Walking in 8 Different Direction Task. |
